# Quart admin
A tool to create quart projects faster with a scalable setup

# Usage
Creating peoject
```sh
quart-admin startproject --name "project name"
```

Creating app(inside project)
```sh
quart-admin startapp --name "app name"
```

Run the app locally
```sh
python app.py start
```